Reporting Issues
----------------

Feature requests and bug reports can be posted at
`Roman Attribute Dictionary's github page <https://github.com/spacetelescope/rad>`_.

Contributing Code and Documentation
-----------------------------------

We love contributions! If you're interested in contributing to this project, please open a Pull Request
or issue and we would be glad to work with you.
